# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkLabelStatisticsKeepNObjectsImageFilterPython
else:
    import _itkLabelStatisticsKeepNObjectsImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_New():
    return itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2.New()

class itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_GetBackgroundValue(self)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_GetNumberOfObjects(self)

    def SetNumberOfObjects(self, _arg):
        r"""
        SetNumberOfObjects(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetNumberOfObjects(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsKeepNObjectsImageFilterPython.delete_itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2

        Create a new object of the class itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2 in _itkLabelStatisticsKeepNObjectsImageFilterPython:
_itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2_swigregister(itkLabelStatisticsKeepNObjectsImageFilterIUC2IF2)

def itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_New():
    return itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2.New()

class itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_GetBackgroundValue(self)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_GetNumberOfObjects(self)

    def SetNumberOfObjects(self, _arg):
        r"""
        SetNumberOfObjects(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetNumberOfObjects(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS2"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsKeepNObjectsImageFilterPython.delete_itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2

        Create a new object of the class itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2 in _itkLabelStatisticsKeepNObjectsImageFilterPython:
_itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2_swigregister(itkLabelStatisticsKeepNObjectsImageFilterIUC2ISS2)

def itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_New():
    return itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2.New()

class itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_GetBackgroundValue(self)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_GetNumberOfObjects(self)

    def SetNumberOfObjects(self, _arg):
        r"""
        SetNumberOfObjects(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetNumberOfObjects(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC2"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsKeepNObjectsImageFilterPython.delete_itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2

        Create a new object of the class itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2 in _itkLabelStatisticsKeepNObjectsImageFilterPython:
_itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2_swigregister(itkLabelStatisticsKeepNObjectsImageFilterIUC2IUC2)

def itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_New():
    return itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3.New()

class itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_GetBackgroundValue(self)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_GetNumberOfObjects(self)

    def SetNumberOfObjects(self, _arg):
        r"""
        SetNumberOfObjects(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetNumberOfObjects(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsKeepNObjectsImageFilterPython.delete_itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3

        Create a new object of the class itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3 in _itkLabelStatisticsKeepNObjectsImageFilterPython:
_itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3_swigregister(itkLabelStatisticsKeepNObjectsImageFilterIUC3IF3)

def itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_New():
    return itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3.New()

class itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_GetBackgroundValue(self)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_GetNumberOfObjects(self)

    def SetNumberOfObjects(self, _arg):
        r"""
        SetNumberOfObjects(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetNumberOfObjects(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS3"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsKeepNObjectsImageFilterPython.delete_itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3

        Create a new object of the class itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3 in _itkLabelStatisticsKeepNObjectsImageFilterPython:
_itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3_swigregister(itkLabelStatisticsKeepNObjectsImageFilterIUC3ISS3)

def itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_New():
    return itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3.New()

class itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_Pointer"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_GetBackgroundValue(self)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_GetNumberOfObjects(self)

    def SetNumberOfObjects(self, _arg):
        r"""
        SetNumberOfObjects(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetNumberOfObjects(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC3"""
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsKeepNObjectsImageFilterPython.delete_itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3

        Create a new object of the class itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3 in _itkLabelStatisticsKeepNObjectsImageFilterPython:
_itkLabelStatisticsKeepNObjectsImageFilterPython.itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3_swigregister(itkLabelStatisticsKeepNObjectsImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def label_statistics_keep_n_objects_image_filter(*args: itkt.ImageLike,  background_value: int=..., number_of_objects: int=..., reverse_ordering: bool=..., attribute: Union[str, int]=..., feature_image: itkt.Image=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for LabelStatisticsKeepNObjectsImageFilter"""
    import itk

    kwarg_typehints = { 'background_value':background_value,'number_of_objects':number_of_objects,'reverse_ordering':reverse_ordering,'attribute':attribute,'feature_image':feature_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.LabelStatisticsKeepNObjectsImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def label_statistics_keep_n_objects_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.LabelStatisticsKeepNObjectsImageFilter
    label_statistics_keep_n_objects_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    label_statistics_keep_n_objects_image_filter.__doc__ = filter_object.__doc__



